//
//  ColorPickerChannelModel.swift
//  ColorPicker
//
//  Created by Akira Hayashi on 2022/09/21.
//

import SwiftUI

class ColorPickerChannelModel : ObservableObject {
    /// チャネル名
    @Published var channelName: String
    
    /// 現在値
    @Published var currentValue: Double = 0.0
    
    init(channelName: String) {
        self.channelName = channelName
    }
    
    /// 入力中のテキスト
    private var fieldTextStore: String?
    
    /// 入力中のテキストのバインディング
    var fieldText: Binding<String> {
        Binding {
            self.fieldTextStore ?? String(format: "%g", self.currentValue)
        } set: {
            self.fieldTextStore = $0
            if let value = Double($0) {
                self.changeCurrentValue(value)
            }
        }

    }
    
    /// 現在値の更新
    func changeCurrentValue(_ value: Double) {
        if value < 0.0 {
            currentValue = 0.0
        } else if value > 1.0 {
            currentValue = 1.0
        } else {
            currentValue = value
        }
    }
    
    /// 入力中のテキストをクリア
    func clearFieldText() {
        fieldTextStore = nil
    }
}
