//
//  ColorPickerGradationModel.swift
//  ColorPicker
//
//  Created by Akira Hayashi on 2022/09/21.
//

import SwiftUI

class ColorPickerGradationModel : ObservableObject {
    /// グラデーションビューのサイズ
    @Published var viewSize: CGSize = CGSize()
    /// グラデーションの開始色
    @Published var startColor: Color
    /// グラデーションの終了色
    @Published var endColor: Color
    
    /// イニシャライザ
    /// - Parameters:
    ///     - startColor: グラデーションの開始色
    ///     - endColor: グラデーションの終了色
    init(startColor: Color, endColor: Color) {
        self.startColor = startColor
        self.endColor = endColor
    }
}

extension ColorPickerGradationModel {
    
    /// RGBカラーモデルのRedチャネル
    static var red: ColorPickerGradationModel {
        ColorPickerGradationModel(startColor: Color(red: 0.0, green: 0.0, blue: 0.0),
                                  endColor: Color(red: 1.0, green: 0.0, blue: 0.0))
    }
    
    /// RGBカラーモデルのGreenチャネル
    static var green: ColorPickerGradationModel {
        ColorPickerGradationModel(startColor: Color(red: 0.0, green: 0.0, blue: 0.0),
                                  endColor: Color(red: 0.0, green: 1.0, blue: 0.0))
    }
    
    /// RGBカラーモデルのBlueチャネル
    static var blue: ColorPickerGradationModel {
        ColorPickerGradationModel(startColor: Color(red: 0.0, green: 0.0, blue: 0.0),
                                  endColor: Color(red: 0.0, green: 0.0, blue: 1.0))
    }
}
