//
//  PickerGradationView.swift
//  ColorPicker
//
//  Created by Akira Hayashi on 2022/09/02.
//

import SwiftUI

struct PickerGradationView: View {
    @ObservedObject var channel: ColorPickerChannelModel
    @ObservedObject var gradation: ColorPickerGradationModel
    
    /// ノブの大きさ
    let indicatorSize: CGFloat = 20
    /// グラデーションビューの高さ
    let gradationHeigh: CGFloat = 100
    
    /// ノブのX座標
    var indicatorX: CGFloat {
        gradation.viewSize.width * channel.currentValue - indicatorSize / 2
    }
    
    var drag: some Gesture {
        DragGesture()
            .onChanged { dragValue in
                channel.changeCurrentValue(dragValue.location.x / gradation.viewSize.width)
                channel.clearFieldText()
            }
    }
    
    var body: some View {
        ZStack(alignment: .leading) {
            GeometryReader() { geometry in
                LinearGradient(gradient: Gradient(colors: [gradation.startColor, gradation.endColor]), startPoint: UnitPoint(x: 0, y: 0), endPoint: UnitPoint(x: 1, y: 0))
            }
            .frame(height: gradationHeigh)
            .background {
                GeometryReader { geometry in
                    Path { path in
                        Task.detached {
                            await updateViewSize(geometry.size)
                        }
                    }
                }
            }
            .onTapGesture { point in
                channel.currentValue = point.x / gradation.viewSize.width
                channel.clearFieldText()
            }
            .gesture(drag)

            PickerIndicator()
                .frame(width: indicatorSize, height: indicatorSize)
                .offset(x: indicatorX)
        }
    }
    
    @MainActor
    func updateViewSize(_ size: CGSize) async {
        if size != gradation.viewSize {
            gradation.viewSize = size
        }
    }
}

struct PickerGradationView_Previews: PreviewProvider {
    static var previews: some View {
        PickerGradationView(channel: ColorPickerChannelModel(channelName: "Red"), gradation: .red)
            .padding()
    }
}
